package com.ruoyi.system.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.JSONWriter;
import com.ruoyi.common.core.constant.Constants;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.domain.StrFile;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.ServletUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.file.FileUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.security.service.TokenService;
import com.ruoyi.system.api.RemoteFileService;
import com.ruoyi.system.api.domain.SysFile;
import com.ruoyi.system.api.domain.SysUser;
import com.ruoyi.system.api.model.LoginUser;
import com.ruoyi.system.domain.SnServer;
import com.ruoyi.system.domain.SnServerTask;
import com.ruoyi.system.domain.SnServerTemplate;
import com.ruoyi.system.domain.SnTemplate;
import com.ruoyi.system.domain.dto.DeploySSLParams;
import com.ruoyi.system.domain.dto.UpdateBaseParams;
import com.ruoyi.system.kernel.CreateShellTaskKernel;
import com.ruoyi.system.kernel.DomainValidKernel;
import com.ruoyi.system.kernel.SslCountLimit;
import com.ruoyi.system.kernel.SslNginxConfigDealKernel;
import com.ruoyi.system.mapper.SnServerMapper;
import com.ruoyi.system.mapper.SnServerTaskMapper;
import com.ruoyi.system.mapper.SnServerTemplateMapper;
import com.ruoyi.system.mapper.SnTemplateMapper;
import com.ruoyi.system.mq.ServerTaskSender;
import com.ruoyi.system.service.ISnServerTemplateService;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.system.utils.FileConversionUtil;
import com.ruoyi.system.utils.RequestUtil;
import com.ruoyi.system.utils.SSLExpirationChecker;
import com.ruoyi.system.utils.ZipTool;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.function.Function;
import java.util.stream.Collectors;
import org.apache.commons.lang3.tuple.Pair;
import org.apache.commons.lang3.tuple.Triple;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

@RefreshScope
@Service
public class SnServerTemplateServiceImpl implements ISnServerTemplateService {
   @Autowired
   private SnServerTemplateMapper snServerTemplateMapper;
   @Autowired
   private TokenService tokenService;
   @Autowired
   private DomainValidKernel domainValidKernel;
   @Autowired
   private SnServerMapper snServerMapper;
   @Autowired
   private SnTemplateMapper snTemplateMapper;
   @Autowired
   private RemoteFileService remoteFileService;
   @Autowired
   private CreateShellTaskKernel createShellTaskKernel;
   @Autowired
   private ServerTaskSender serverTaskSender;
   @Autowired
   private ISysDictDataService dictDataService;
   @Autowired
   private SslNginxConfigDealKernel sslNginxConfigDealKernel;
   @Autowired
   private ISysUserService sysUserService;
   @Autowired
   private SslCountLimit sslCountLimit;
   @Autowired
   private SnServerTaskMapper snServerTaskMapper;
   @Value("${baseNginxUrl}")
   public String baseNginxUrl;
   @Value("${wpPluginName}")
   public String wpPluginName;

   public AjaxResult getOwnLast(Long serverId) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      return AjaxResult.success(this.snServerTemplateMapper.getOwnLast(serverId, loginUser.getUserid()));
   }

   public SnServerTemplate selectSnServerTemplateById(Long id) {
      SnServerTemplate obj = this.snServerTemplateMapper.selectSnServerTemplateById(id);
      if (obj != null && !obj.getIsDelete().equals(1)) {
         LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
         if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            if (loginUser.getRoles().contains("dealer")) {
               return obj.getDealerId().equals(loginUser.getUserid()) ? obj : null;
            } else if (loginUser.getRoles().contains("agent")) {
               return obj.getAgentId().equals(loginUser.getUserid()) ? obj : null;
            } else {
               return obj.getCreateId().equals(loginUser.getUserid()) ? obj : null;
            }
         } else {
            return obj;
         }
      } else {
         return null;
      }
   }

   public List<SnServerTemplate> selectSnServerTemplateList(SnServerTemplate obj) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      if (loginUser.getRoles().contains("dealer")) {
         obj.setDealerId(loginUser.getUserid());
      }

      if (loginUser.getRoles().contains("agent")) {
         obj.setAgentId(loginUser.getUserid());
      }

      if (loginUser.getRoles().contains("common")) {
         obj.setCreateId(loginUser.getUserid());
      }

      obj.setIsDelete(0);
      if (StringUtils.isNotEmpty(obj.getCategory())) {
         obj.getParams().put("categoryList", obj.getCategory().split(","));
      }

      return this.snServerTemplateMapper.selectSnServerTemplateList(obj);
   }

   public AjaxResult insertSnServerTemplate(SnServerTemplate param) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      SnServer server = this.snServerMapper.selectSnServerByServerId(param.getServerId());
      if (server == null) {
         return AjaxResult.error("未查询到服务器信息");
      } else if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(server.getCreateId(), loginUser.getUserid()) && !Objects.equals(server.getAgentId(), loginUser.getUserid())) {
         return AjaxResult.error("您无权操作此服务器");
      } else if (!Objects.equals(server.getStatus(), 2)) {
         return AjaxResult.error("此服务器处于【" + this.dictDataService.selectDictLabel("server_status", server.getStatus().toString()) + "】状态，不能安装模板");
      } else {
         SnTemplate template = this.snTemplateMapper.selectSnTemplateByTemplateId(param.getTemplateId());
         if (template == null) {
            return AjaxResult.error("未获取到模板，请联系管理员");
         } else if (!Objects.equals(template.getStatus(), 1)) {
            return AjaxResult.error("当前模板已下架，请选择其他模板");
         } else if (template.getCategory() == 6) {
            return this.generateWp(param, template, server);
         } else {
            Pair<SnServerTask, String> pair = this.insertTemplate(param, template, server);
            if (pair.getLeft() != null) {
               this.serverTaskSender.sendOrderMessage(((SnServerTask)pair.getLeft()).getTaskId());
            }

            return StringUtils.isNotEmpty((String)pair.getRight()) ? AjaxResult.error((String)pair.getRight()) : AjaxResult.success("部署中，请稍后查看服务器任务状态");
         }
      }
   }

   private AjaxResult generateWp(SnServerTemplate param, SnTemplate template, SnServer server) {
      String domain = param.getDomain();
      SnServerTemplate query = new SnServerTemplate();
      query.setTemplateId(param.getTemplateId());
      query.setServerId(param.getServerId());
      query.getParams().put("domain", domain);
      query.setIsDelete(0);
      if (!this.snServerTemplateMapper.selectSnServerTemplateList(query).isEmpty()) {
         return AjaxResult.error("当前服务器已生成相同域名的插件，请到插件列表查看");
      } else {
         try {
            Path newZipPath = ZipTool.generateWpPlugin(template.getPackUrl(), domain, server.getDomain(), this.wpPluginName);
            MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
            R<SysFile> fileResult = this.remoteFileService.upload(file);
            ZipTool.deleteDirectory(newZipPath);
            if (!StringUtils.isNull(fileResult) && !StringUtils.isNull(fileResult.getData())) {
               String url = ((SysFile)fileResult.getData()).getUrl();
               SnServerTemplate obj = new SnServerTemplate(server, template);
               obj.setDomain(domain);
               obj.setStatus(2);
               obj.setNginxCnf(url);
               this.snServerTemplateMapper.insertSnServerTemplate(obj);
               this.snTemplateMapper.updateSnTemplateUseNum(template.getTemplateId());
               return AjaxResult.success(obj);
            } else {
               return AjaxResult.error("生成插件异常，请稍后再试");
            }
         } catch (Exception var11) {
            return AjaxResult.error("生成插件异常，请稍后再试");
         }
      }
   }

   @Transactional
   public Pair<SnServerTask, String> insertTemplate(SnServerTemplate param, SnTemplate template, SnServer server) {
      String domain = param.getDomain();
      AjaxResult result = this.domainValidKernel.checkDomain(domain, server.getIp(), (Long)null);
      if (!result.isSuccess()) {
         return Pair.of((Object)null, (String)result.get("msg"));
      } else {
         String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
         nginxConfig = nginxConfig.replace("#{server_name}", domain);
         nginxConfig = nginxConfig.replace("#{client_root}", "");
         nginxConfig = nginxConfig.replace("#{open_80}", "");
         StrFile strFile = new StrFile();
         strFile.setContent(nginxConfig);
         strFile.setFileName(domain + ".conf");
         strFile.setContentType("text/plain");
         R<SysFile> r1 = this.remoteFileService.uploadStrToMinio(strFile);
         if (r1.getCode() != Constants.SUCCESS) {
            return Pair.of((Object)null, r1.getMsg());
         } else {
            String nginxUrl = ((SysFile)r1.getData()).getUrl();
            SnServerTemplate obj = new SnServerTemplate(server, template);
            obj.setDomain(domain);
            obj.setNginxCnf(nginxUrl);
            obj.setProcess(param.getProcess());
            this.snServerTemplateMapper.insertSnServerTemplate(obj);
            SnServerTask task = this.createShellTaskKernel.installClient(obj, template);
            if (task.getProcess() != null) {
               SnServer upObj = new SnServer();
               upObj.setServerId(server.getServerId());
               upObj.setTaskId(task.getTaskId());
               this.snServerMapper.updateSnServer(upObj);
            }

            this.snTemplateMapper.updateSnTemplateUseNum(template.getTemplateId());
            return Pair.of(task, (Object)null);
         }
      }
   }

   public int updateSnServerTemplate(SnServerTemplate snServerTemplate) {
      if (this.selectSnServerTemplateById(snServerTemplate.getId()) == null) {
         return 0;
      } else {
         LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
         snServerTemplate.setUpdateId(loginUser.getUserid());
         snServerTemplate.setUpdateName(loginUser.getUsername());
         snServerTemplate.setUpdateTime(DateUtils.getNowDate());
         return this.snServerTemplateMapper.updateSnServerTemplate(snServerTemplate);
      }
   }

   public int deleteSnServerTemplateByIds(Long[] ids) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      SnServerTemplate query = new SnServerTemplate();
      query.getParams().put("serverTemplateIds", ids);
      List<SnServerTemplate> templates = this.snServerTemplateMapper.selectSnServerTemplateList(query);
      if (templates.isEmpty()) {
         return 0;
      } else {
         SnServer server = this.snServerMapper.selectSnServerByServerId(((SnServerTemplate)templates.get(0)).getServerId());
         templates.forEach((template) -> {
            SnServerTask task = this.createShellTaskKernel.deleteClient(server, template);
            if (task != null) {
               if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
                  return;
               }

               this.serverTaskSender.sendOrderMessage(task.getTaskId());
            }

         });
         Long createId = null;
         if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            createId = loginUser.getUserid();
            return this.snServerTemplateMapper.deleteSnServerTemplateByIdsV2(ids, createId);
         } else {
            return this.snServerTemplateMapper.deleteSnServerTemplateByIds(ids);
         }
      }
   }

   public AjaxResult changeDomain(SnServerTemplate param) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      SnServerTemplate template = this.selectSnServerTemplateById(param.getId());
      if (template == null) {
         return AjaxResult.error("未查询到服务器客户端信息");
      } else if (!Objects.equals(template.getStatus(), 2)) {
         return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能更换域名");
      } else if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
         return AjaxResult.error("您无权操作此服务器客户端");
      } else {
         String oldDomain = template.getDomain();
         String domain = param.getDomain();
         if (Objects.equals(oldDomain, domain)) {
            return AjaxResult.warn("域名已应用到当前服务器，请勿重复操作");
         } else {
            AjaxResult result = this.domainValidKernel.checkDomain(domain, template.getServerIp(), (Long)null);
            if (!result.isSuccess()) {
               return result;
            } else {
               AjaxResult res = this.updateClientConfig(template, domain, (Integer)null);
               if (!res.isSuccess()) {
                  return res;
               } else {
                  String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
                  nginxConfig = nginxConfig.replace("#{server_name}", domain);
                  nginxConfig = nginxConfig.replace("#{client_root}", "");
                  nginxConfig = nginxConfig.replace("#{open_80}", "");
                  StrFile strFile = new StrFile();
                  strFile.setContent(nginxConfig);
                  strFile.setFileName(domain + ".conf");
                  strFile.setContentType("text/plain");
                  R<SysFile> r1 = this.remoteFileService.uploadStrToMinio(strFile);
                  if (r1.getCode() != Constants.SUCCESS) {
                     return AjaxResult.error(r1.getMsg());
                  } else {
                     String nginxUrl = ((SysFile)r1.getData()).getUrl();
                     SnServerTemplate upObj = new SnServerTemplate();
                     upObj.setId(template.getId());
                     upObj.setDomain(domain);
                     upObj.setNginxCnf(nginxUrl);
                     upObj.setSslType(0);
                     this.updateSnServerTemplate(upObj);
                     SnServerTask task = this.createShellTaskKernel.changeClientDomain(this.snServerTemplateMapper.selectSnServerTemplateById(template.getId()), oldDomain);
                     if (task != null) {
                        this.serverTaskSender.sendOrderMessage(task.getTaskId());
                     }

                     return AjaxResult.success("更新中，请稍后查看服务器任务状态");
                  }
               }
            }
         }
      }
   }

   public AjaxResult deployDomainSSL(DeploySSLParams params) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      SnServerTemplate template = this.selectSnServerTemplateById(params.getId());
      if (template == null) {
         return AjaxResult.error("未查询到服务器信息");
      } else if (!Objects.equals(template.getStatus(), 2)) {
         return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能部署ssl证书");
      } else if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
         return AjaxResult.error("您无权操作此服务器客户端");
      } else {
         String domain = template.getDomain();
         if (params.getType() == 1) {
            AjaxResult res = this.sslCountLimit.validCount(domain, template.getServerIp());
            if (!res.isSuccess()) {
               return res;
            }
         }

         if (this.snServerTaskMapper.haveDealTask(template.getServerId(), "ssl证书", "0,1") > 0) {
            return AjaxResult.error("当前服务还有未执行完的ssl证书任务，请稍后再试");
         } else {
            SnServerTemplate upObj = new SnServerTemplate();
            upObj.setId(template.getId());
            if (params.getType() == 2) {
               upObj.setSslTime(SSLExpirationChecker.getCertificateExDate(params.getSslPem()));
            }

            String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
            SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
            Triple<AjaxResult, DeploySSLParams, String> triple = this.sslNginxConfigDealKernel.deal(params, server, domain, nginxConfig);
            if (!((AjaxResult)triple.getLeft()).isSuccess()) {
               return (AjaxResult)triple.getLeft();
            } else {
               nginxConfig = (String)triple.getRight();
               params = (DeploySSLParams)triple.getMiddle();
               nginxConfig = nginxConfig.replace("#{client_root}", "");
               upObj.setSslPem(params.getSslPem());
               upObj.setSslKey(params.getSslKey());
               upObj.setSslType(0);
               StrFile strFile = new StrFile();
               strFile.setContent(nginxConfig);
               strFile.setFileName(domain + ".conf");
               strFile.setContentType("text/plain");
               R<SysFile> r1 = this.remoteFileService.uploadStrToMinio(strFile);
               if (r1.getCode() != Constants.SUCCESS) {
                  return AjaxResult.error(r1.getMsg());
               } else {
                  String nginxUrl = ((SysFile)r1.getData()).getUrl();
                  upObj.setNginxCnf(nginxUrl);
                  upObj.setSslType(params.getType());
                  this.updateSnServerTemplate(upObj);
                  SnServerTask task = this.createShellTaskKernel.deploySSL(this.snServerTemplateMapper.selectSnServerTemplateById(template.getId()), params);
                  if (task != null) {
                     this.serverTaskSender.sendOrderMessage(task.getTaskId());
                     if (task.getProcess() != null) {
                        SnServer upServer = new SnServer();
                        upServer.setServerId(server.getServerId());
                        upServer.setTaskId(task.getTaskId());
                        this.snServerMapper.updateSnServer(upServer);
                     }
                  }

                  return AjaxResult.success("部署中，请稍后查看服务器任务状态");
               }
            }
         }
      }
   }

   public AjaxResult updateUI(UpdateBaseParams params) {
      LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
      SnServerTemplate template = this.selectSnServerTemplateById(params.getId());
      if (template == null) {
         return AjaxResult.error("未查询到服务器信息");
      } else if (!Objects.equals(template.getStatus(), 2)) {
         return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能更新UI");
      } else if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
         return AjaxResult.error("您无权操作此服务器客户端");
      } else {
         SnTemplate font = this.snTemplateMapper.selectSnTemplateByTemplateId(template.getTemplateId());
         if (font == null) {
            return AjaxResult.error("未获取到模板，请联系管理员");
         } else if (!Objects.equals(font.getStatus(), 1)) {
            return AjaxResult.error("当前模板已下架");
         } else if (Objects.equals(template.getVersion(), font.getVersion())) {
            return AjaxResult.error("当前已是最新版本");
         } else {
            params.setVersion(font.getVersion());
            params.setPackUrl(font.getPackUrl());
            SnServerTemplate upObj = new SnServerTemplate();
            upObj.setId(template.getId());
            upObj.setVersion(font.getVersion());
            if (Objects.equals(font.getCategory(), 6)) {
               try {
                  SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
                  Path newZipPath = ZipTool.generateWpPlugin(font.getPackUrl(), template.getDomain(), server.getDomain(), this.wpPluginName);
                  MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
                  R<SysFile> fileResult = this.remoteFileService.upload(file);
                  ZipTool.deleteDirectory(newZipPath);
                  if (StringUtils.isNull(fileResult) || StringUtils.isNull(fileResult.getData())) {
                     return AjaxResult.error("生成插件异常，请稍后再试");
                  }

                  String url = ((SysFile)fileResult.getData()).getUrl();
                  upObj.setNginxCnf(url);
               } catch (Exception var11) {
                  return AjaxResult.error("生成插件异常，请稍后再试");
               }
            } else {
               SnServerTask task = this.createShellTaskKernel.updateUI(template, params);
               if (task != null) {
                  this.serverTaskSender.sendOrderMessage(task.getTaskId());
               }
            }

            this.updateSnServerTemplate(upObj);
            return AjaxResult.success("部署中，请稍后查看服务器任务状态");
         }
      }
   }

   public AjaxResult haveUpdate(UpdateBaseParams params) {
      SnServerTemplate obj = new SnServerTemplate();
      obj.setServerId(params.getId());
      obj.setStatus(2);
      List<SnServerTemplate> templates = this.selectSnServerTemplateList(obj);
      if (templates.isEmpty()) {
         return AjaxResult.success("操作成功", false);
      } else {
         Long[] templateIds = (Long[])templates.stream().map(SnServerTemplate::getTemplateId).distinct().toArray((x$0) -> {
            return new Long[x$0];
         });
         SnTemplate snTemplate = new SnTemplate();
         snTemplate.getParams().put("excludeBack", 1);
         snTemplate.getParams().put("templateIds", templateIds);
         List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
         Map<Long, SnTemplate> tempMap = (Map)tempList.stream().collect(Collectors.toMap(SnTemplate::getTemplateId, Function.identity()));
         boolean haveUpdate = Boolean.FALSE;
         Iterator var9 = templates.iterator();

         while(var9.hasNext()) {
            SnServerTemplate template = (SnServerTemplate)var9.next();
            SnTemplate font = (SnTemplate)tempMap.get(template.getTemplateId());
            if (font != null && params.getTypes().contains(font.getCategory()) && Objects.equals(font.getStatus(), 1) && !Objects.equals(template.getVersion(), font.getVersion())) {
               haveUpdate = Boolean.TRUE;
               break;
            }
         }

         return AjaxResult.success("操作成功", haveUpdate);
      }
   }

   public List<JSONObject> haveUpdateDetail(Long serverId) {
      SnServerTemplate obj = new SnServerTemplate();
      obj.setServerId(serverId);
      obj.setStatus(2);
      List<SnServerTemplate> templates = this.snServerTemplateMapper.selectSnServerTemplateList(obj);
      if (templates.isEmpty()) {
         return new ArrayList();
      } else {
         Long[] templateIds = (Long[])templates.stream().map(SnServerTemplate::getTemplateId).distinct().toArray((x$0) -> {
            return new Long[x$0];
         });
         SnTemplate snTemplate = new SnTemplate();
         snTemplate.getParams().put("excludeBack", 1);
         snTemplate.getParams().put("templateIds", templateIds);
         List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
         Map<Long, SnTemplate> tempMap = (Map)tempList.stream().collect(Collectors.toMap(SnTemplate::getTemplateId, Function.identity()));
         List<JSONObject> list = new ArrayList();

         JSONObject json;
         for(Iterator var9 = templates.iterator(); var9.hasNext(); list.add(json)) {
            SnServerTemplate template = (SnServerTemplate)var9.next();
            json = new JSONObject();
            json.put("version", template.getVersion());
            json.put("domain", template.getDomain());
            SnTemplate font = (SnTemplate)tempMap.get(template.getTemplateId());
            if (font != null) {
               json.put("category", font.getCategory());
               json.put("templateName", font.getName());
               json.put("country", font.getCountry());
               json.put("language", font.getLanguage());
               if (Objects.equals(font.getStatus(), 1)) {
                  json.put("versionNew", font.getVersion());
               }
            }
         }

         return list;
      }
   }

   public AjaxResult updateAllUI(UpdateBaseParams params) {
      SnServerTemplate obj = new SnServerTemplate();
      obj.setServerId(params.getId());
      obj.setStatus(2);
      List<SnServerTemplate> templates = this.selectSnServerTemplateList(obj);
      if (templates.isEmpty()) {
         return AjaxResult.error("未查询到服务器信息");
      } else {
         Long[] templateIds = (Long[])templates.stream().map(SnServerTemplate::getTemplateId).distinct().toArray((x$0) -> {
            return new Long[x$0];
         });
         SnTemplate snTemplate = new SnTemplate();
         snTemplate.getParams().put("excludeBack", 1);
         snTemplate.getParams().put("templateIds", templateIds);
         List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
         Map<Long, SnTemplate> tempMap = (Map)tempList.stream().collect(Collectors.toMap(SnTemplate::getTemplateId, Function.identity()));
         SnServer server = this.snServerMapper.selectSnServerByServerId(((SnServerTemplate)templates.get(0)).getServerId());
         List<JSONObject> updates = new ArrayList();
         Iterator var10 = templates.iterator();

         while(true) {
            while(true) {
               while(true) {
                  SnServerTemplate template;
                  JSONObject json;
                  SnTemplate font;
                  label45:
                  do {
                     while(var10.hasNext()) {
                        template = (SnServerTemplate)var10.next();
                        json = new JSONObject();
                        json.put("templateId", template.getId());
                        json.put("templateName", template.getTemplateName());
                        json.put("domain", template.getDomain());
                        font = (SnTemplate)tempMap.get(template.getTemplateId());
                        if (font != null) {
                           continue label45;
                        }

                        json.put("result", "未获取到模板");
                        updates.add(json);
                     }

                     return AjaxResult.success("操作成功", updates);
                  } while(!params.getTypes().contains(font.getCategory()));

                  if (Objects.equals(font.getStatus(), 1)) {
                     if (!Objects.equals(template.getVersion(), font.getVersion())) {
                        params.setVersion(font.getVersion());
                        params.setPackUrl(font.getPackUrl());
                        SnServerTemplate upObj = new SnServerTemplate();
                        upObj.setId(template.getId());
                        upObj.setVersion(font.getVersion());
                        if (Objects.equals(font.getCategory(), 6)) {
                           try {
                              Path newZipPath = ZipTool.generateWpPlugin(font.getPackUrl(), template.getDomain(), server.getDomain(), this.wpPluginName);
                              MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
                              R<SysFile> fileResult = this.remoteFileService.upload(file);
                              ZipTool.deleteDirectory(newZipPath);
                              if (StringUtils.isNull(fileResult) || StringUtils.isNull(fileResult.getData())) {
                                 return AjaxResult.error("生成插件异常，请稍后再试");
                              }

                              String url = ((SysFile)fileResult.getData()).getUrl();
                              upObj.setNginxCnf(url);
                              json.put("result", "部署中");
                           } catch (Exception var19) {
                              return AjaxResult.error("生成插件异常，请稍后再试");
                           }
                        } else {
                           SnServerTask task = this.createShellTaskKernel.updateUI(template, params);
                           if (task != null) {
                              this.serverTaskSender.sendOrderMessage(task.getTaskId());
                           }

                           json.put("result", "部署中");
                        }

                        this.updateSnServerTemplate(upObj);
                        updates.add(json);
                     } else {
                        json.put("result", "已是最新版本");
                        updates.add(json);
                     }
                  } else {
                     json.put("result", "当前模板已下架");
                     updates.add(json);
                  }
               }
            }
         }
      }
   }

   public AjaxResult updateClientConfig(SnServerTemplate template, String domain, Integer category) {
      SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
      SysUser common = this.sysUserService.selectUserById(server.getCreateId());
      String url = (server.getSslType() != null && server.getSslType() != 0 ? "https://" : "http://") + server.getDomain() + "/api/user/config/updateDomain";
      JSONObject params = (new JSONObject()).fluentPut("license", common.getLicense()).fluentPut("serverTemplateId", template.getId()).fluentPut("domain", domain).fluentPut("category", category);
      String res = (new RequestUtil()).doPostJson(url, params.toJSONString(new JSONWriter.Feature[0]));
      System.out.println("更新客户端域名结果：" + res);

      try {
         JSONObject json = JSONObject.parseObject(res);
         return !Objects.equals(json.getInteger("code"), 200) ? AjaxResult.error("更新客户端域名失败，请稍后再试") : AjaxResult.success();
      } catch (Exception var10) {
         return AjaxResult.error("更新客户端域名失败，请稍后再试");
      }
   }
}
